@@ -7,19 +7,6 @@
 #
 # MWetter@lbl.gov                            2015-11-17
 #######################################################
-#
-# import from future to make Python2 behave like Python3
-from __future__ import absolute_import
-from __future__ import division
-from __future__ import print_function
-from __future__ import unicode_literals
-from future import standard_library
-standard_library.install_aliases()
-from builtins import *
-from io import open
-# end of from future import
-
-
 class ErrorDictionary(object):
     """ Class that contains data fields needed for the
         error checking of the regression tests.
