@@ -6,20 +6,6 @@
 #
 # MWetter@lbl.gov                            2014-04-15
 #######################################################
-#
-# import from future to make Python2 behave like Python3
-from __future__ import absolute_import
-from __future__ import division
-from __future__ import print_function
-from __future__ import unicode_literals
-from future import standard_library
-standard_library.install_aliases()
-from builtins import *
-from io import open
-from shutil import copyfile
-# end of from future import
-
-
 class IBPSA(object):
     """ Class that merges the
         `Modelica IBPSA Library <https://github.com/ibpsa/modelica-ibpsa>`_
@@ -30,7 +16,7 @@ class IBPSA(object):
         By default, the top-level packages `Experimental`
         and `Obsolete` are not included in the merge.
         This can be overwritten with the function
-        :meth:`~set_excluded_packages`.
+        :meth:`~set_excluded_directories`.
 
     """
 
@@ -64,18 +50,28 @@ class IBPSA(object):
         self._new_library_name = os.path.basename(dest_dir)
 
         # Exclude packages and files
-        self.set_excluded_packages(["Experimental",
-                                    "Obsolete"])
+        self.set_excluded_directories(["Experimental",
+                                       "Obsolete",
+                                       ".FMUOutput"])
         self._excluded_files = [os.path.join(ibpsa_dir, "package.mo"),
                                 os.path.join(ibpsa_dir, "dymosim"),
+                                os.path.join(ibpsa_dir, "dymosim.exe"),
+                                os.path.join(ibpsa_dir, "request"),
+                                os.path.join(ibpsa_dir, "status"),
+                                os.path.join(ibpsa_dir, "success"),
                                 os.path.join(ibpsa_dir, "ds*.txt"),
                                 os.path.join(ibpsa_dir, "*.c"),
+                                os.path.join(ibpsa_dir, "*.exe"),
                                 os.path.join(ibpsa_dir, "*.csv"),
                                 os.path.join(ibpsa_dir, "*.log"),
                                 os.path.join(ibpsa_dir, "*.mat"),
                                 os.path.join(ibpsa_dir, "*.fmu"),
                                 os.path.join(ibpsa_dir, "*.mos"),
                                 os.path.join(ibpsa_dir, "*.mof"),
+                                os.path.join(ibpsa_dir, "*.pyc"),
+                                os.path.join(ibpsa_dir, "*.pdf"),
+                                os.path.join(ibpsa_dir, "*.svg"),
+                                os.path.join(ibpsa_dir, "*.pyc"),
                                 os.path.join(ibpsa_dir, "nohup.out"),
                                 os.path.join(ibpsa_dir, "funnel_comp", "plot.html"),
                                 os.path.join(ibpsa_dir, "funnel_comp", "**", "*.csv"),
@@ -84,6 +80,8 @@ class IBPSA(object):
                                              "Scripts", "Dymola", "ConvertIBPSA_from_*.mos"),
                                 os.path.join(ibpsa_dir, "Resources",
                                              "Scripts", "travis", "Makefile"),
+                                os.path.join(ibpsa_dir, "Resources",
+                                             "Scripts", "github-actions", "jmodelica", "jm_ipython.sh"),
                                 os.path.join(ibpsa_dir, "Resources",
                                              "Scripts", "BuildingsPy", "conf.json"),
                                 os.path.join(ibpsa_dir, "Resources", "Scripts",
@@ -93,15 +91,15 @@ class IBPSA(object):
                                 os.path.join(ibpsa_dir, "Resources", "www", "modelicaDoc.css"),
                                 os.path.join(ibpsa_dir, "legal.html")]
 
-    def set_excluded_packages(self, packages):
-        """ Set the packages that are excluded from the merge.
+    def set_excluded_directories(self, directories):
+        """ Set the directories that are excluded from the merge.
 
-        :param packages: A list of packages to be excluded.
+        :param packages: A list of directories to be excluded.
 
         """
-        if not isinstance(packages, list):
+        if not isinstance(directories, list):
             raise ValueError("Argument must be a list.")
-        self._excluded_packages = packages
+        self._excluded_directories = directories
 
     def _copy_mo_and_mos(self, source_file, destination_file):
         """ Update the library name and do other replacements that
@@ -122,26 +120,34 @@ class IBPSA(object):
                         "Buildings.HeatTransfer.Sources.FixedTemperature"})
             # The merge script updates a few names that have IBPSA in it but
             # that should not be updated. Here, we revert this renaming.
-        rep[self._src_library_name] = self._new_library_name
+        #rep[self._src_library_name] = self._new_library_name
         rep.update({"{} Conference".format(self._new_library_name):
                     "IBPSA Conference",
                     "2013-{}-Wetter.pdf".format(self._new_library_name):
                     "2013-IBPSA-Wetter.pdf"})
-        self._copy_rename(source_file, destination_file, rep)
+        self._copy_rename("IBPSA", self._new_library_name, source_file, destination_file, rep)
 
-    def _copy_rename(self, src, des, rep):
+    def _copy_rename(self, src_library, des_library, src, des, rep):
         """ Read source file `src` and write to destination file `des` with the dictionary entries replaced in the new content of the new file.
 
+            :param src_library: Name of the source library.
+            :param des_library: Name of the destination library.
             :param src: Name of the source file.
             :param des: Name of the destination file.
             :param rep: Dictionary where each key is the string to be replaced in the new file with its value.
         """
         from collections import OrderedDict
+        import re
 
         lines = list()
         try:
             with open(src, mode="r", encoding="utf-8") as f_sou:
                 for _, lin in enumerate(f_sou):
+                    # Don't replace IBPSA if it is part of 'digit''digit'\"> as in
+                    # <a href=\"https://github.com/ibpsa/modelica-ibpsa/issues/1454\">IBPSA, #1454</a>.
+                    lin = re.sub(
+                        r"(?<!(\d\d\\\">))({src_lib})".format(
+                            src_lib=src_library), des_library, lin)
                     for ori, new in list(rep.items()):
                         lin = lin.replace(ori, new)
                     lines.append(lin)
@@ -217,7 +223,7 @@ class IBPSA(object):
         if '*' in pattern:
             pat = pattern.split('*')
             # Currently, we only support one wild card character
-            if len(pat) is not 2:
+            if len(pat) != 2:
                 ValueError("Pattern {} is not supported.".format(pattern))
             # Make sure it has the same number of directories
             ret = filter(lambda x: (x.count(os.path.sep) == pattern.count(os.path.sep)) and
@@ -311,7 +317,7 @@ class IBPSA(object):
         filesToCopy = list()
 
         for root, dirs, files in os.walk(self._ibpsa_home, topdown=True):
-            dirs[:] = [d for d in dirs if d not in self._excluded_packages]
+            dirs[:] = [d for d in dirs if d not in self._excluded_directories]
             for file in files:
                 filesToCopy.append(os.path.join(root, file))
 
@@ -358,9 +364,9 @@ class IBPSA(object):
                 elif desFil.startswith(ref_res):
                     dir_name = os.path.dirname(desFil)
                     base_name = os.path.basename(desFil)
-                    # Check if the file needs be skipped because it is from an excluded package.
+                    # Check if the file needs be skipped because it is from an excluded directory.
                     skip = False
-                    for pac in self._excluded_packages:
+                    for pac in self._excluded_directories:
                         if "{}_{}".format(self._src_library_name, pac) in base_name:
                             skip = True
                     if not skip:
@@ -398,9 +404,13 @@ class IBPSA(object):
                                 is_binary = True
                                 break
                         if is_binary:
-                            copyfile(srcFil, new_file)
+                            shutil.copyfile(srcFil, new_file)
                         else:
-                            self._copy_rename(srcFil, new_file, rep)
+                            self._copy_rename(self._src_library_name,
+                                              self._new_library_name,
+                                              srcFil,
+                                              new_file,
+                                              rep)
 
                 # Copy all other files. This may be images, C-source, libraries etc.
                 else:
